

set -ex



gdal_grid --version
gdal_rasterize --version
gdal_translate --version
gdaladdo --version
gdalenhance --version
gdalwarp --version
gdalinfo --formats
bash /var/folders/sy/f16zz6x50xz3113nwtb9bvq00000gp/T/abs_fdl32tfypv/clone/recipe/run_test.sh
exit 0
